#include "MyDetectorConstruction.hh"

#include "G4Material.hh"
#include "G4Box.hh"
#include "G4LogicalVolume.hh"
#include "G4ThreeVector.hh"
#include "G4PVPlacement.hh"
#include "globals.hh"


MyDetectorConstruction::MyDetectorConstruction() :  
  experimentalHall_log(0),
  experimentalHall_phys(0)
{}


MyDetectorConstruction::~MyDetectorConstruction() {}


G4VPhysicalVolume* MyDetectorConstruction::Construct() {

  // Only the experimental all is present.
  // It is filled with Argon gas.
  // Its dimensions are: 4m x 4m x 4m 
  // (which means from -2m to +2m in each coordinate,
  //  the origin being in the center).

  //------------------- materials ------------------------

  G4double a;  // atomic mass
  G4double z;  // atomic number
  G4double density;
  G4String name;

  a = 39.95*g/mole;
  density = 1.782e-03*g/cm3;
  G4Material* Ar = new G4Material(name="ArgonGas", z=18., a, density);

  //------------------- volumes --------------------------

  // --- experimental hall (world volume)
  //     beam line along x axis

  G4double expHall_x = 2.0*m;  // half dimension along x 
  G4double expHall_y = 2.0*m;  // half dimension along y
  G4double expHall_z = 2.0*m;  // half dimension along z

  G4Box* experimentalHall_box
    = new G4Box("expHall_box",expHall_x,expHall_y,expHall_z);

  experimentalHall_log = new G4LogicalVolume(experimentalHall_box, // solid 
                                             Ar,                   // material
					     "expHall_log",        // name
					     0,                    // field manager
					     0,                    // sensitive detector
					     0);                   // user limits

  experimentalHall_phys = new G4PVPlacement(0,                     // rotation
					    G4ThreeVector(),       // translation
					    "expHall",             // name
                                            experimentalHall_log,  // logical volume
					    0,                     // mother physical volume
					    false,                 // boolean operation
					    0);                    // copy number

  //------------------------------------------------------------------

  return experimentalHall_phys;
}

