#include "MyAnalysis.hh"

#include "G4RunManager.hh" 

#include <AIDA/AIDA.h>


MyAnalysis* MyAnalysis::instance = 0;

 
MyAnalysis::MyAnalysis() : 
  analysisFactory(0), tree(0), tuple(0), 
  edepCaloHisto(0) {

  analysisFactory = AIDA_createAnalysisFactory();
  if (analysisFactory) {    
    AIDA::ITreeFactory* treeFactory = analysisFactory->createTreeFactory();
    if (treeFactory) {
      // Tree in memory: create a "tree" associated to an hbook file.
      bool readOnly = false; // we want to write.
      bool createNew = true; // create file if it doesn't exist.

      //***LOOKHERE*** FIRST LINE FOR ANAPHE, SECOND ONE FOR JAS.
      tree = treeFactory->create("my.his", "hbook", readOnly, createNew);
      //tree = treeFactory->create("my.aida", "xml", readOnly, createNew);

      if (tree) {
	// Get a tuple factory :
	AIDA::ITupleFactory* tupleFactory = analysisFactory->createTupleFactory(*tree);
	if (tupleFactory) {
	  // Create a tuple :
	  string tag = "float ECAL";
	  //tuple = tupleFactory->create("1","Event info", tag); // Column wise (default)
	  tuple = tupleFactory->create("1","Event info", tag, "--preferRWN"); // Row wise
	  assert(tuple);
	  delete tupleFactory;
	}
	AIDA::IHistogramFactory* histoFactory	= 
	  analysisFactory->createHistogramFactory(*tree);  
	if (histoFactory) {
	  // Create histos.
 	  edepCaloHisto = histoFactory->createHistogram1D("10", 
							  "Edep in Active calo layer, in MeV", 
							  100, 0., 1.0);
	  delete histoFactory;
	}    
      }
      delete treeFactory; // It will not delete the ITree.
    }
  }
}


MyAnalysis::~MyAnalysis() {
  if (tree) {
    delete tree;
    tree = 0;
  }
  if (analysisFactory) {
    delete analysisFactory;
    analysisFactory = 0;
  }
}


MyAnalysis* MyAnalysis::getInstance() {
  if (instance == 0) instance = new MyAnalysis();
  return instance;
}


void MyAnalysis::init() {
  if (edepCaloHisto) edepCaloHisto->reset();
  if (tuple) tuple->reset();
}                       


void MyAnalysis::finish() {             
  if (tree) {
    tree->commit();
    tree->close();
  }
}


void MyAnalysis::fillCaloHistos(float edep) {
  if ( edepCaloHisto ) {
    edepCaloHisto->fill(edep);
  }
}


void MyAnalysis::fillNtuple(float edepCalo) {
  if (tuple) {
    tuple->fill(tuple->findColumn("ECAL"), edepCalo);
    tuple->addRow();
  }
}

