#include "G4RunManager.hh"
#include "G4UImanager.hh"

#include "MyDetectorConstruction.hh"
#include "MyPhysicsList.hh"
#include "MyPrimaryGeneratorAction.hh"

#include "G4UIterminal.hh"
#ifdef G4VIS_USE
  #include "MyVisManager.hh"
#endif


int main(int argc,char** argv) {

  // Construct the default run manager
  G4RunManager* runManager = new G4RunManager;

#ifdef G4VIS_USE
  MyVisManager *visManager = new MyVisManager;
  visManager->Initialize();
#endif        

  // set mandatory initialization classes
  runManager->SetUserInitialization(new MyDetectorConstruction);
  runManager->SetUserInitialization(new MyPhysicsList);

  // set mandatory user action class
  runManager->SetUserAction(new MyPrimaryGeneratorAction);

  // Initialize G4 kernel
  runManager->Initialize();

  G4UImanager* UI = G4UImanager::GetUIpointer();  
  if ( argc==1 ) {   // Define UI session for interactive mode.

#ifdef G4VIS_USE
    // Create empty scene
    G4String visCommand = "/vis/scene/create";
    UI->ApplyCommand(visCommand);
    // Choose one default viewer (you can always change it later on) 
    // visCommand = "/vis/open VRML2FILE";
    // visCommand = "/vis/open VRML2";
    visCommand = "/vis/open OGLIX";
    UI->ApplyCommand(visCommand);
    visCommand = "/vis/viewer/flush";
    UI->ApplyCommand(visCommand);
#endif

    G4UIsession* session = new G4UIterminal(); // simple "dumb" terminal.
    session->SessionStart();
    delete session;

  } else {   // Batch mode

    G4String command = "/control/execute ";
    G4String fileName = argv[1];
    UI->ApplyCommand(command+fileName);

  }

  // job termination
#ifdef G4VIS_USE
  delete visManager;
#endif
  delete runManager;
  return 0;

}


