#include "MyDetectorMessenger.hh"

#include "MyDetectorConstruction.hh"
#include "G4UIdirectory.hh"
#include "G4UIcmdWithADoubleAndUnit.hh"
#include "globals.hh"


MyDetectorMessenger::MyDetectorMessenger(MyDetectorConstruction* myDet)
  : myDetector(myDet), mydetDir(0), FieldCmd(0) { 

  mydetDir = new G4UIdirectory("/mydet/");
  mydetDir->SetGuidance("Detector control.");
  
  FieldCmd = new G4UIcmdWithADoubleAndUnit("/mydet/setField",this);  
  FieldCmd->SetGuidance("Define magnetic field.");
  FieldCmd->SetGuidance("Magnetic field will be in X direction.");
  FieldCmd->SetParameterName("Bx",false);
  FieldCmd->SetDefaultUnit("tesla");
  FieldCmd->SetUnitCategory("Magnetic flux density");
  FieldCmd->AvailableForStates(G4State_PreInit,G4State_Idle);  
}


MyDetectorMessenger::~MyDetectorMessenger() {
  delete FieldCmd;
  delete mydetDir;
}


void MyDetectorMessenger::SetNewValue(G4UIcommand* command, G4String newValue) { 
  if ( command == FieldCmd ) { 
    myDetector->SetMagField( FieldCmd->GetNewDoubleValue(newValue) );
  }
}

