#include "MyPhysicsList.hh"
#include "G4ParticleTypes.hh"
#include "G4ProcessManager.hh"
#include "G4Gamma.hh"
#include "G4Electron.hh"
#include "G4Positron.hh"
#include "G4NeutrinoE.hh"
#include "G4AntiNeutrinoE.hh"
#include "G4PhotoElectricEffect.hh"
#include "G4ComptonScattering.hh"
#include "G4GammaConversion.hh"
#include "G4MultipleScattering.hh"
#include "G4eIonisation.hh"
#include "G4eBremsstrahlung.hh"
#include "G4eplusAnnihilation.hh"


MyPhysicsList::MyPhysicsList() {}


MyPhysicsList::~MyPhysicsList() {}


void MyPhysicsList::ConstructParticle() {
  // In this method, static member functions should be called
  // for all particles which you want to use.
  // This ensures that objects of these particle types will be
  // created in the program. 

  G4Geantino::GeantinoDefinition();
  G4Gamma::GammaDefinition();
  G4Electron::ElectronDefinition();
  G4Positron::PositronDefinition();
  G4NeutrinoE::NeutrinoEDefinition();
  G4AntiNeutrinoE::AntiNeutrinoEDefinition();
}


void MyPhysicsList::ConstructProcess() {
  // Define transportation process

  AddTransportation();

  G4ProcessManager * pManager = 0;
  
  pManager = G4Gamma::Gamma()->GetProcessManager();
  pManager->AddProcess(new G4PhotoElectricEffect(),    -1, -1, 1);
  pManager->AddProcess(new G4ComptonScattering(),      -1, -1, 2);
  pManager->AddProcess(new G4GammaConversion(),        -1, -1, 3);

  pManager = G4Electron::Electron()->GetProcessManager();
  pManager->AddProcess(new G4MultipleScattering(),     -1, 1, 1);  
  pManager->AddProcess(new G4eIonisation(),            -1, 2, 2);
  pManager->AddProcess(new G4eBremsstrahlung(),         -1,-1, 3);

  pManager = G4Positron::Positron()->GetProcessManager();
  pManager->AddProcess(new G4MultipleScattering(),     -1, 1, 1);  
  pManager->AddProcess(new G4eIonisation(),            -1, 2, 2);
  pManager->AddProcess(new G4eBremsstrahlung(),         -1,-1, 3);
  pManager->AddProcess(new G4eplusAnnihilation(),       1,-1, 4);

}


void MyPhysicsList::SetCuts() {
  // uppress error messages even in case e/gamma/proton do not exist            
  G4int temp = GetVerboseLevel(); 
  SetVerboseLevel(0);

  //  " G4VUserPhysicsList::SetCutsWithDefault" method sets 
  //   the default cut value for all particle types 
  SetCutsWithDefault();   

  // Retrieve verbose level
  SetVerboseLevel(temp);  
}

